Jeff Latimer : usp10: Tidy default values.

Alexandre Julliard julliard at wine.codeweavers.com
Fri Feb 24 14:29:42 CST 2006


Module: wine
Branch: refs/heads/master
Commit: ec6744490d6ac1f4db8690061dd14ff69ba3e6c2
URL:    http://source.winehq.org/git/?p=wine.git;a=commit;h=ec6744490d6ac1f4db8690061dd14ff69ba3e6c2

Author: Jeff Latimer <lats at yless4u.com.au>
Date:   Fri Feb 24 20:13:51 2006 +1100

usp10: Tidy default values.
Set values for pwLogClust, uJustification and fClusterStart similar to
what Windows uses.

---

 dlls/usp10/usp10.c |   12 +++++-------
 1 files changed, 5 insertions(+), 7 deletions(-)

diff --git a/dlls/usp10/usp10.c b/dlls/usp10/usp10.c
index a150274..c02689d 100644
--- a/dlls/usp10/usp10.c
+++ b/dlls/usp10/usp10.c
@@ -297,12 +297,11 @@ HRESULT WINAPI ScriptShape(HDC hdc, SCRI
     HDC phdc;
     int cnt;
     DWORD hr;
-    int clusterinit;
     Scriptcache *pScriptcache;
     *pcGlyphs = cChars;
     FIXME("(%p, %p, %p, %d, %d, %p): semi-stub\n",  hdc, psc, pwcChars,
                                        cChars, cMaxGlyphs, psa);
-    if (psa) TRACE("%d, %d, %d, %d, %d, %d, %d\n", psa->eScript, psa->fRTL, psa->fLayoutRTL,
+    if (psa) TRACE("psa values: %d, %d, %d, %d, %d, %d, %d\n", psa->eScript, psa->fRTL, psa->fLayoutRTL,
                                          psa->fLinkBefore, psa->fLinkAfter,
                                          psa->fLogicalOrder, psa->fNoGlyphIndex);
 
@@ -348,14 +347,13 @@ HRESULT WINAPI ScriptShape(HDC hdc, SCRI
        TRACE("\n");
     }
 
-    /*  Set up a valid SCRIPT_VISATTR for this run */     
-    clusterinit = 1;                        /* Start of Cluster */
+    /*  Set up a valid SCRIPT_VISATTR and LogClust for each char in this run */     
     for (cnt = 0;  cnt < cChars; cnt++) {
-         psva[cnt].uJustification = 0;
-         psva[cnt].fClusterStart = clusterinit;
-         clusterinit = 0;
+         psva[cnt].uJustification = 2;
+         psva[cnt].fClusterStart = 1;
          psva[cnt].fDiacritic = 0;
          psva[cnt].fZeroWidth = 0;
+         pwLogClust[cnt] = cnt;
     }
     return 0; 
 }




More information about the wine-cvs mailing list